Changelog
=========

%%version%% (unreleased)
------------------------

- Update __init__.py. [dessant]

- Update copyright year. [dessant]

- Fix windows filechooser using `mode` instead of `self.mode` [gabriel
  pettier]

- Merge pull request #144 from thegrymek/plyer-audio. [dessant]

  Plyer audio for android with facade and example

- Update docs facade with permissions. [andrzej.grymkowski]

- Improving docs. [andrzej.grymkowski]

- Corrected "" in docstring. [Andrzej Grymkowski]

- Flake8. [Andrzej Grymkowski]

- Update readme. [Andrzej Grymkowski]

- Removing temporary files. [Andrzej Grymkowski]

- Moved example class to facades. [Andrzej Grymkowski]

- Impoved example. [andrzej.grymkowski]

- Added almost working example. [Andrzej Grymkowski]

- Initial commit. [Andrzej Grymkowski]

- Merge pull request #147 from kivy/stylefix. [dessant]

  style fixes

- Style fixes. [dessant]

- Merge pull request #146 from kivy/dessant-patch-1. [dessant]

  add pydev files to gitignore

- Add pydev files to gitignore. [dessant]

- Merge pull request #145 from thegrymek/plyer-style-guide-update.
  [dessant]

  Plyer style guide update

- Another improvements. [andrzej.grymkowski]

- Corrected win filechooser. [andrzej.grymkowski]

- Update for docs. [andrzej.grymkowski]

- Improved styles in files. [andrzej.grymkowski]

- Updated kivy pep8 and corrected some files. [andrzej.grymkowski]

- Merge pull request #143 from kivy/dessant-patch-1. [dessant]

  fix versionchanged tag

- Fix versionchanged tag. [dessant]

- Merge pull request #133 from aron-bordin/master. [dessant]

  fix #107 - Use Android_ID instead of IMEI

- Fix #107 - Use Android_ID instead of IMEI. [Aron Bordin]

- Merge pull request #140 from thegrymek/plyer-android4.0-email.
  [dessant]

  update info about support email for android<4.0

- Update info to readme about support email on android<4.0.
  [andrzej.grymkowski]

- Merge pull request #135 from thegrymek/inclement-orientation.
  [dessant]

  Inclement orientation

- Adding tag versionadded to facade. [andrzej.grymkowski]

- Fix for import facade orientation. [Andrzej Grymkowski]

- Added to readme supported platforms platform android < 4.0. [Andrzej
  Grymkowski]

- Removing red functions label. [Andrzej Grymkowski]

- Corrected readme. [Andrzej Grymkowski]

- Updated orientation. [Andrzej Grymkowski]

- Merge pull request #139 from thegrymek/plyer-add-package-facades-
  setuptools. [dessant]

  added plyer.facade to setuptools package

- Added plyer.facade to setuptools package. [Andrzej Grymkowski]

- Merge pull request #138 from thegrymek/plyer-split-facades. [dessant]

  splitted facades

- Changed order. [Andrzej Grymkowski]

- Spliting end. [Andrzej Grymkowski]

- Spliting end. [Andrzej Grymkowski]

- First part. [Andrzej Grymkowski]

- Merge pull request #129 from thegrymek/android-vibrator-sdk-9.
  [dessant]

  vibrator for android v < 4.0

- Added defaults. [Andrzej Grymkowski]

- Removing files  tests. [Andrzej Grymkowski]

- A. [Andrzej Grymkowski]

- Merging. [Andrzej Grymkowski]

- Replace """ in docstrings" [Andrzej Grymkowski]

- Added exist for sdk < 11. [Andrzej Grymkowski]

- Added unsupported exception. [Andrzej Grymkowski]

- Removed unnessesary docstrings. [Andrzej Grymkowski]

- Conflicts main. [Andrzej Grymkowski]

- Updated document. [Andrzej Grymkowski]

- Vibrator for android v < 4.0, pep257 and flake8. [Andrzej Grymkowski]

- Updated document. [Andrzej Grymkowski]

- Remove unnessesary docstring. [Andrzej Grymkowski]

- Merging. [Andrzej Grymkowski]

- Merge branch 'new_branch_name' [Andrzej Grymkowski]

- Merge. [Andrzej Grymkowski]

- Remove unused variables. [thegrymek]

- PEP8 and typo fixes in MacOS X file chooser. [Robert Jerovsek]

- Removed unused imports and refactor. [Andrzej Grymkowski]

- Pep8 - removed unused imports and variables. [Andrzej Grymkowski]

- Make pep8 compatible. [laltin]

- Responds to issue 109 https://github.com/kivy/plyer/issues/109.
  [albericc]

- As. [Andrzej Grymkowski]

- Added first structure. [Andrzej Grymkowski]

- Merge pull request #1 from kivy/master. [thegrymek]

  sync pull request

- Merge pull request #134 from thegrymek/patch-1. [dessant]

  remove unused variables

- Remove unused variables. [thegrymek]

- Merge pull request #110 from AlbericC/issue_109. [dessant]

  responds to issue 109 https://github.com/kivy/plyer/issues/109

- Responds to issue 109 https://github.com/kivy/plyer/issues/109.
  [albericc]

- Merge pull request #121 from laltin/pep8_fix. [Mathieu Virbel]

  Pep8 fix

- Make pep8 compatible. [laltin]

- Merge pull request #1 from kivy/master. [Lütfi Altın]

  sync with origin

- Merge pull request #122 from thegrymek/pep8-removed-unused-imports-
  and-variables. [Mathieu Virbel]

  pep8 - removed unused imports and variables

- Removed unused imports and refactor. [Andrzej Grymkowski]

- Pep8 - removed unused imports and variables. [Andrzej Grymkowski]

- Merge pull request #123 from robertjerovsek/master. [Mathieu Virbel]

  PEP8 and typo fixes in MacOS X file chooser.

- PEP8 and typo fixes in MacOS X file chooser. [Robert Jerovsek]

- Merge pull request #106 from Davideddu/filechooser. [Mathieu Virbel]

  Add file chooser facade and support for Linux and Windows

- Fix filter conversion on Mac OS X. [Davide Depau]

- Add experimental support for Mac OS X. [Davide Depau]

- Fix inheritance issue on windows filechooser implementation. [Davide
  Depau]

- Add filechooser facade and support for Linux and Windows. [Davide
  Depau]

- Merge pull request #119 from trivedigaurav/use-environ-lang. [Mathieu
  Virbel]

  Use environ to change LANG to 'C' while calling shell processes

- Use environ to change LANG to 'C' while calling shell processes.
  [gtrivedi]

- Merge pull request #120 from pspchucky/master. [Mathieu Virbel]

  add video recoding to Camera facade and camera.py

- Update camera.py. [pspchucky]

- Add video capture support to facades.py. [pspchucky]

- Merge pull request #118 from kived/irblaster-facade. [Akshay Arora]

  add IrBlaster facade and Android implementation

- Add IrBlaster facade and Android implementation. [Ryan Pessa]

- Update README.rst. [Mathieu Virbel]

- Merge pull request #116 from laltin/ios_gps. [Mathieu Virbel]

  iOS GPS support

- Cleanup & comment. [laltin]

- First working version. [laltin]

- Merge pull request #115 from kivy/fixes_114. [Mathieu Virbel]

  use environ to change LANG to 'C' while calling lshw

- Use environ to change LANG to 'C' while calling lshw. [gabriel
  pettier]

  fixes #114

- Merge pull request #117 from JimmyStavros/patch-1. [Mathieu Virbel]

  Android gps.py: fixed location provider cycling

- Android gps.py: fixed location provider cycling. [JimmyStavros]

  Issue was first brought to light here: https://github.com/kivy/plyer/issues/54

  GPS module was cycling through "gps" three times instead of all location services.

- Fixes hashCode overflow. Latest kivy/pyjnius master have already
  hashCode/equals/toString implementation, and the hashCode is fixed
  with overflow. Just dont try to implement it here. Closes #103. Ref
  kivy/pyjnius#146. [Mathieu Virbel]

- Bump to 1.2.4-dev. [Mathieu Virbel]

1.2.3 (2015-01-27)
------------------

- Bump to 1.2.3. [Mathieu Virbel]

- Setup.py: add changelog into the description + fix rst issue. [Mathieu
  Virbel]

- Bump to 1.2.3-dev. [Mathieu Virbel]

1.2.2 (2015-01-27)
------------------

- Bump to 1.2.2. [Mathieu Virbel]

- Update the version to the next dev (missing from the last release)
  [Mathieu Virbel]

- Merge branch 'master' of ssh://github.com/kivy/plyer. [Mathieu Virbel]

- Merge pull request #102 from helenst/sys-platform-linux-check.
  [Mathieu Virbel]

  Linux platform check made compatible with python 3.3+ (Fixes #58)

- Linux platform check made compatible with python 3.3+ (Fixes #58)
  [Helen ST]

- Add initial changelog. [Mathieu Virbel]

- Plyer: fix androidd notification. Closes #93 (credits to @kashifpk)
  [Mathieu Virbel]

- Android/notification: implement a switch to allow usage of API < 16.
  [Mathieu Virbel]

1.2.1 (2014-08-19)
------------------

- Merge pull request #92 from dessant/patch-2. [trivedigaurav]

  fix print statement

- Fix print statement. [dessant]

- SMS Manager is supported since Android 1.6. [trivedigaurav]

- Merge pull request #90 from trivedigaurav/ios_uuid. [trivedigaurav]

  iOS UUID facade

- IOS UUID facade. [gtrivedi]

- Merge pull request #86 from trivedigaurav/ios_battery. [trivedigaurav]

  iOS Battery

- Change get_status to get_state. [gtrivedi]

- Clean up. [gtrivedi]

- Add battery.py. [gtrivedi]

- IOS Battery Facade. [gtrivedi]

- Update compass.py. [trivedigaurav]

- Update gyroscope.py. [trivedigaurav]

- Fix typo. [trivedigaurav]

- Fix typo. [trivedigaurav]

- Fix style. [gtrivedi]

- Merge branch 'trivedigaurav-ios_tts' [gtrivedi]

- Fixing README confict and merge master. [gtrivedi]

- Merge pull request #88 from trivedigaurav/ios_email. [trivedigaurav]

  iOS Email Facade

- Add email.py. [gtrivedi]

- Merge branch 'master' of https://github.com/kivy/plyer into ios_email.
  [gtrivedi]

- Merge pull request #89 from trivedigaurav/fix_make. [trivedigaurav]

  Removing build_ext from plyer

- Removing build_ext from plyer. [gtrivedi]

- Update accelerometer.py. [trivedigaurav]

- Python 3 compat. [trivedigaurav]

- Python 3 compat. [trivedigaurav]

- Python 3 compat. [trivedigaurav]

- IOS Email Facade. [gtrivedi]

- Merge pull request #82 from trivedigaurav/sensors_start_none.
  [trivedigaurav]

  Fix Android enable and disable. Return (None, None, None) until sensor data is available

- Fix sensor enable-disable. [gtrivedi]

- Merge branch 'master' of https://github.com/kivy/plyer into
  sensors_start_none. [gtrivedi]

- Merge pull request #68 from trivedigaurav/linux_accel. [trivedigaurav]

  Linux accelerometer facade

- Linux accelerometer facade. [gtrivedi]

- Fix style error. [trivedigaurav]

- Merge pull request #85 from trivedigaurav/battery_ischarging.
  [trivedigaurav]

  Change connected to isCharging

- Change connected to isCharging. [gtrivedi]

- Merge pull request #80 from ChrisCole42/patch-2. [trivedigaurav]

  Update compass.py

- Update compass.py. [ChrisCole42]

  copied the missing definitions across from accelerometer.py

- Merge pull request #79 from trivedigaurav/where_is. [trivedigaurav]

  Use whereis_exe to check for binaries

- Remove trailing newline. [gtrivedi]

- Add whereis_exe import. [gtrivedi]

- Remove trailing newline. [gtrivedi]

- Use whereis_exe to check for binaries. [gtrivedi]

- Fix style errors. [gtrivedi]

- Copy values atomically. [gtrivedi]

- Return None untill data is available. [gtrivedi]

- Merge pull request #77 from ChrisCole42/patch-1. [trivedigaurav]

  Update compass.py

- Update compass.py. [ChrisCole42]

  fix "global name is not defined" error in AndroidCompass.__init__()

- Merge pull request #75 from trivedigaurav/maintenance. [trivedigaurav]

  Maintenance merge

- Remove extra make command. [gtrivedi]

- Merge branch 'master' of https://github.com/kivy/plyer into
  maintenance. [gtrivedi]

  Conflicts:
  	plyer/facades.py

- Changed battery Xs to correct columns (ios -> win) [Alexander Taylor]

- Really did fix battery formatting in readme. [Alexander Taylor]

- Fixed battery formatting in readme. [Alexander Taylor]

- Merge pull request #74 from dessant/patch-1. [Akshay Arora]

  facade docstring revision

- Facade docstring revision. [dessant]

- Merge pull request #73 from trivedigaurav/battery_info. [Akshay Arora]

  Query Battery info/status

- Merge pull request #71 from trivedigaurav/master. [trivedigaurav]

  Revert "Activity was imported twice"

- Revert "Activity was imported twice" [gtrivedi]

  This reverts commit a0600929774c1e90c7dc43043ff87b5ea84213b4.

- Activity was imported twice. [trivedigaurav]

- Fix style errors after merging with master. [gtrivedi]

- Fix styles errors in libs/ [gtrivedi]

- Don't ignore lib folder. [gtrivedi]

- Fix style errors. [gtrivedi]

- Fix docstrings. [gtrivedi]

- Fix typo and style. [gtrivedi]

- Copy pep8 style checker from Kivy. [gtrivedi]

- Add Makefile. [gtrivedi]

- Add windows implementation. [gtrivedi]

- Fix android implemenation typos. [gtrivedi]

- Battery facade. [gtrivedi]

- Merge branch 'master' of https://github.com/kivy/plyer into
  battery_info. [gtrivedi]

  Conflicts:
  	plyer/__init__.py

- Merge pull request #70 from trivedigaurav/master. [trivedigaurav]

  Fix tabbing

- Merge pull request #69 from trivedigaurav/gyroscope_fix.
  [trivedigaurav]

  Gyroscope facade proxy declarations

- Gyroscope facade proxy declarations. [gtrivedi]

- Merge pull request #67 from trivedigaurav/patch-1. [Akshay Arora]

  Update README.rst

- Update README.rst. [trivedigaurav]

  We have merged commits for the email facades on desktops.

- Merge branch 'master' of https://github.com/trivedigaurav/plyer into
  battery_info. [gtrivedi]

- Fix tabbing. [trivedigaurav]

  Not sure how this passed through.

- Battery facade. [gtrivedi]

- Typo. [Mathieu Virbel]

- Ios: gyroscope is also supported now. [Mathieu Virbel]

1.2.0 (2014-06-24)
------------------

- Bump to 1.2.0, and mark new classes to 1.2.0. [Mathieu Virbel]

- Merge master. [Mathieu Virbel]

- Remove dependency on Hardware.java. [gtrivedi]

- IOS and Android implementations. [gtrivedi]

- Gyroscope facade. [gtrivedi]

- Add gyroscope in README. [gtrivedi]

- Merge branch 'master' of ssh://github.com/kivy/plyer. [Mathieu Virbel]

- Merge pull request #49 from Davideddu/macosx_email. [Mathieu Virbel]

  add Mac OS X email support

- Add Mac OS X email support. [Davide Depau]

- Merge pull request #48 from Davideddu/windows_email. [Mathieu Virbel]

  add Windows email support

- Catch exception if no email client is installed on Windows. [Davide
  Depau]

- Add Windows email support. [Davide Depau]

- Merge pull request #47 from Davideddu/linux_email. [Mathieu Virbel]

  added Linux email support

- Revert previous commit, use xdg-open to open email client. [Davide
  Depau]

- Use xdg-email by default, fallback to xdg-open + mailto uri. [Davide
  Depau]

- Added Linux email support. [Davide Depau]

- Merge master. [Mathieu Virbel]

- Remove gyroscope files. [gtrivedi]

- Fix typos introduced while copying. [gtrivedi]

- Fix typo. [gtrivedi]

- Fix tabbing. [gtrivedi]

- IOS Magnetometer. [gtrivedi]

- Merge branch 'master' of ssh://github.com/kivy/plyer. [Mathieu Virbel]

- Merge pull request #63 from trivedigaurav/pyjnius_accel. [Mathieu
  Virbel]

  Switched to pyjnius

- Make values assignment atomic. [gtrivedi]

- Switched to pyjnius. [gtrivedi]

- Merge master. [Mathieu Virbel]

- Plyer Unique ID facade. [gtrivedi]

- Merge master. [Mathieu Virbel]

- Update README. [trivedigaurav]

- Merge branch 'android_compass' of
  https://github.com/trivedigaurav/plyer into android_compass.
  [gtrivedi]

- Update buildozer.spec. [trivedigaurav]

- Pyjnius compass. [gtrivedi]

- Update buildozer.spec. [gtrivedi]

- Plyer compass facade. [gtrivedi]

- Merge pull request #52 from mihaineacsu/sms. [Mathieu Virbel]

  Added sms facade, example and android implementation

- Updated sms components. [mihaineacsu]

- Fix components of the sms facade. [mihaineacsu]

- Update README with sms feature. [mihaineacsu]

- Update plyer init. [mihaineacsu]

- Add sms example. [mihaineacsu]

- Add initial android sms implementation. [mihaineacsu]

- Add sms facade. [mihaineacsu]

- Merge pull request #55 from trivedigaurav/osx_accel. [Mathieu Virbel]

  Using sudden motion sensor as accelerometer on OSX

- Check accelerometer in OSX. [gtrivedi]

- LGPL notice no longer required. [gtrivedi]

- Fix tabs to spaces. [gtrivedi]

- Switched to ctypes. [gtrivedi]

- Remove osx libs in setup.py. [gtrivedi]

- Added LGPL.txt for unimotion.c. [gtrivedi]

- Added libs/ folder in macosx. [gtrivedi]

- OSX Accel facade using unimotion. [gtrivedi]

- Merge pull request #62 from trivedigaurav/patch-2. [Mathieu Virbel]

  Update README

- Update README. [trivedigaurav]

- Merge pull request #56 from trivedigaurav/patch-1. [Akshay Arora]

  Update README

- Update README. [trivedigaurav]

- Remove buildozer db. [Mathieu Virbel]

- Merge pull request #46 from matham/master. [akshayaurora]

  Add compat module, remove decoding of strings in notification

- Explicitly declare HANDLE since ctypes in py3 doesn't seem to have it.
  [Matthew Einhorn]

- Make py3 compat. [Matthew Einhorn]

- Decode textinput input before sending to notification. [Matthew
  Einhorn]

- Add compat module, remove decoding of strings in notification, do
  direct inmport instead of relative import. [Matthew Einhorn]

- Removed unused import. [Ben Rousch]

- Merge pull request #6 from inclement/vibrate. [Alexander Taylor]

  Added Vibrator facade and android implementation

- Renamed vibrate_pattern to just pattern. [Alexander Taylor]

- Fixed typo in vibrator proxy comment. [Alexander Taylor]

- Added vibrator example and buildozer.spec. [Alexander Taylor]

- Added AndroidVibrator implementation. [Alexander Taylor]

- Added Vibrator facade. [Alexander Taylor]

- Merge pull request #18 from matham/ctypes-notify-window. [Ben Rousch]

  Changes notify to use ctypes instead of win32gui so we could use unicode.

- Use unique id. [Matthew Einhorn]

- Use count instead of self to generate different classes. [Matthew
  Einhorn]

- Add notify_close method and always display some systray icon. [Matthew
  Einhorn]

- Update to use ctypes instead of win32gui so we could use unicode.
  [Matthew Einhorn]

- Add windows ctypes api defs file. [Matthew Einhorn]

- Merge pull request #39 from trivedigaurav/accelerometer_example. [Ben
  Rousch]

  Created an accelerometer example. Uses garden graph to plot the values

- Removed unused variable. [gtrivedi]

- Added a simple accelerometer example. [gtrivedi]

- Corrected README for buildozer commands. [gtrivedi]

- Updated README to reflect path changes. [gtrivedi]

- Moved the graph example to examples/accelerometer/using_graph.
  [gtrivedi]

- Updated README to include information about garden.graph. [gtrivedi]

- Added screenshot of the app running on Android 4.3. [gtrivedi]

- Added README on how to build. [gtrivedi]

- Cleaned up a bit. Newlines. Removed dangling commented lines.
  [gtrivedi]

- Fixed ordering in the try catch block. It fails at the correct line in
  the try block if the accelerometer is not present. [gtrivedi]

- Fixed android permissions. Doesn't require any. [gtrivedi]

- Changed popup error message to state that the problem is with the
  current platform. [gtrivedi]

- Removed a test file not a part of the example. [gtrivedi]

- Created an accelerometer example. Uses garden graph to plot the
  values. [gtrivedi]

- Added examples README. [Ben Rousch]

- Merge pull request #38 from trivedigaurav/tts_example. [Ben Rousch]

  Shows an error popup if there is no TTS

- Added newlines at the end of files. [gtrivedi]

- Shows an error popup if there is no TTS capability. [gtrivedi]

- Merge pull request #37 from trivedigaurav/tts_example. [akshayaurora]

  Text to Speech Example

- Removed an empty line. [gtrivedi]

- Created an example application for the text to speech (tts) facade.
  [gtrivedi]

- Merge pull request #11 from kivy/notification_windows_icon.
  [akshayaurora]

  User-specified icon support for Windows notifications

- Notification: introduce `timeout` [qua-non]

- User-specified icon support for Windows notifications. [Ben Rousch]

- Merge pull request #15 from voen/patch-1. [Ben Rousch]

  readme typo corrected

- Readme typo corrected. [voen]

- Merge pull request #10 from kivy/dbus_notify. [akshayaurora]

  Introduce dbus notification

- Removed attempts at using app_icon in Android notification. [Ben
  Rousch]

- Improve notification example. [qua-non]

- Partial example notification example. [Ben Rousch]

- Introduce dbus notification. [qua-non]

- Fix plyer android.activity import. [Mathieu Virbel]

- Fixed whereis_exe for windows. Fixed espeak TTS for windows. [Ben
  Rousch]

- Merge pull request #5 from inclement/sendemail. [Mathieu Virbel]

  Added an email facade and basic android implementation

- Removed unnecessary import from email. [Alexander Taylor]

- Pep8 fixes. [Alexander Taylor]

- Added email facade example. [Alexander Taylor]

- Added email to README. [Alexander Taylor]

- Completed email facade and android implementation. [Alexander Taylor]

- Added email facade. [Alexander Taylor]

- Added simple buildozer.spec for gps example. [Alexander Taylor]

- Add missing super() constructor in IosAccelerometer. [Mathieu Virbel]

- Ios: add support for accelerometer on iOS (and motivate brousch again)
  [Mathieu Virbel]

- Add MANIFEST to include LICENSE and README. bump to 1.1.2. [Mathieu
  Virbel]

- Bump to 1.1.1. [Mathieu Virbel]

- Fix setup for pip. [Mathieu Virbel]

- Update readme. [Mathieu Virbel]

- Setup.py: fix readme. [Mathieu Virbel]

- Update readme. [Mathieu Virbel]

- Gps: add versionadded. [Mathieu Virbel]

- Fix documentation version. [Mathieu Virbel]

- Gps: update documentation. [Mathieu Virbel]

- Update setup.py to correctly include win. [Mathieu Virbel]

- Merge branch 'master' of ssh://github.com/kivy/plyer. [Mathieu Virbel]

- Add a basic grid to show supported features per os. [tshirtman]

- Custom icon specification for android notification. [Ben Rousch]

- Even more elegant Android notification code. [Ben Rousch]

- Less hacky getPackageName from Android. [Ben Rousch]

- Fixed hasattr bug. Added default icon support for Android
  notifications. [Ben Rousch]

- PEPed up balloontip. Fixed no 2nd notify bug. Fixed blocking
  notification bug. [Ben Rousch]

- Added notifications for Linux via notify-send. [Ben Rousch]

- Fixed name of Windows platform, fixed Windows notify. [Ben Rousch]

- Add GPS/android support for plyer. [Mathieu Virbel]

- Add setup.py. [Mathieu Virbel]

- Plyer is now under MIT license. [Mathieu Virbel]

- Fixed incorrect Android tTS return type. [Ben Rousch]

- Merge pull request #1 from kivy/tts. [Ben Rousch]

  TTS!

- Changed NotImplemented exception to NotImplementedError. [Ben Rousch]

- Added missing () to TTS returns. [Ben Rousch]

- Fixed missed TextToSpeech, deleted old files. [Ben Rousch]

- Changed TextToSpeech to TTS. Returning TTS instead of raising
  NotImplemented. [Ben Rousch]

- Added text_to_speech for Android, Linux, OSX, and Windows. [Ben
  Rousch]

- Ensure the documentation will find plyer. [Mathieu Virbel]

- Rework how implementation works, and start documentation. [Mathieu
  Virbel]

- First version of plyer, including accelerometer (android), camera
  (android) and notification (android, osx). api is not stabilized.
  [Mathieu Virbel]

- Merge branch 'master' of github.com:kivy/plyer. [tshirtman]

  Conflicts:
  	readme.md

- Update readme.md. [Gabriel Pettier]

- Rename to plyer, and uses plateform() from kivy utils. [tshirtman]

- Add android/desktop/ios modules, and auto import from them.
  [tshirtman]

- Initial commit, created simple readme. [tshirtman]


